@@ -3,8 +3,6 @@ from selenium import webdriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from pytest_drivings.local_webdriver import LocalWebDriver
 from pytest_drivings.base_webdriver import BaseWebDriver as RemoteWebDriver
-from _client.v1.client import
-from _client.v1.models.agent import CreateAgentPayload
 from datetime import datetime
 import logging
 from atexit import register
